# drewtils
    
[![Build Status](https://travis-ci.org/drewejohnson/drewtils.svg?branch=master)](https://travis-ci.org/drewejohnson/drewtils)
[![PyPI version](https://badge.fury.io/py/drewtils.svg)](http://badge.fury.io/py/drewtils) 
[![Documentation Status](https://readthedocs.org/projects/drewtils/badge/?version=master)](http://drewtils.readthedocs.io/en/master/?badge=master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/043016e2c680488a8972a9ccd437cdc1)](https://www.codacy.com/app/drewejohnson/drewtils?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=drewejohnson/drewtils&amp;utm_campaign=Badge_Grade)

A collection of utilities that I frequently use.

## Installation
Install with `pip` with ```pip install drewtils``` or through github by 
cloning the repository and running `python setup.py install`

Verify your installation by running `python setup.py test`. 
All tests should pass if the installation completed and the master build is passing.

## Contents
 * `KeywordParser`: Class designed to break a file into chunks based on keyword segments
 * `PatternReader`: Class designed to quickly read a file looking for patterns
 
## Documentation
Documentation is hosted on [readthedocs](http://drewtils.readthedocs.io/en/latest/)
